@@ -16,7 +16,7 @@ use frontend::{
         prelude::{GroupExt, WidgetBase, WidgetExt, WindowExt},
         window,
     },
-    get_frame_time, Compat, DpiScaling, ImgWidget, ImgWidgetExt, Signal, Timer,
+    get_frame_time, Compat, DpiScaling, ImgWidget, ImgWidgetExt, RWHandleExt, Signal, Timer,
 };
 use std::{cell::RefCell, io::Read, rc::Rc, sync::Arc, time::Instant};
 const INTEGRATION_NAME: &str = "egui + fltk + wgpu-backend";
@@ -106,16 +106,24 @@ impl App for ImageDemo {
 
 fn main() {
     let a = app::App::default();
+
+    // Initialize fltk windows with minimal size:
     let mut window = window::Window::default()
-        .with_size(600, 800)
+        .with_size(200, 200)
         .center_screen();
     window.set_label("Image Demo Window");
     window.make_resizable(true);
     window.end();
     window.show();
+
+    // Fix window resizable on fltk 1.2.20+
+    window.set_size(800, 600);
+    window = window.center_screen();
+
     window.make_current();
+
     let instance = wgpu::Instance::new(wgpu::Backends::PRIMARY);
-    let surface = unsafe { instance.create_surface(&window) };
+    let surface = unsafe { instance.create_surface(&window.use_compat()) };
 
     // WGPU 0.11+ support force fallback (if HW implementation not supported), set it to true or false (optional).
     let adapter = pollster::block_on(instance.request_adapter(&wgpu::RequestAdapterOptions {
