@@ -16,23 +16,31 @@ use frontend::{
         prelude::{GroupExt, WidgetBase, WidgetExt, WindowExt},
         window,
     },
-    get_frame_time, DpiScaling, Signal, Timer,
+    get_frame_time, DpiScaling, RWHandleExt, Signal, Timer,
 };
 use std::{cell::RefCell, rc::Rc, sync::Arc, time::Instant};
 const INTEGRATION_NAME: &str = "egui + fltk + wgpu-backend";
 
 fn main() {
     let a = app::App::default();
+
+    // Initialize fltk windows with minimal size:
     let mut window = window::Window::default()
-        .with_size(600, 800)
+        .with_size(200, 200)
         .center_screen();
     window.set_label("Demo Window");
     window.make_resizable(true);
     window.end();
     window.show();
+
+    // Fix window resizable on fltk 1.2.20+
+    window.set_size(800, 600);
+    window = window.center_screen();
+
     window.make_current();
+
     let instance = wgpu::Instance::new(wgpu::Backends::PRIMARY);
-    let surface = unsafe { instance.create_surface(&window) };
+    let surface = unsafe { instance.create_surface(&window.use_compat()) };
 
     // WGPU 0.11+ support force fallback (if HW implementation not supported), set it to true or false (optional).
     let adapter = pollster::block_on(instance.request_adapter(&wgpu::RequestAdapterOptions {
@@ -111,6 +119,7 @@ fn main() {
     let egui_ctx = Rc::new(RefCell::new(CtxRef::default()));
     let repaint_signal = Arc::new(Signal::default());
     let start_time = Instant::now();
+    let mut cpu_usage = get_frame_time(start_time);
     let app_output = Rc::new(RefCell::new(AppOutput::default()));
 
     // Redraw window while being resized (required on windows platform).
@@ -129,17 +138,17 @@ fn main() {
                 if state.window_resized() {
                     window.clear_damage();
                     if let Ok(mut painter) = painter.try_borrow_mut() {
+                        let egui_start = Instant::now();
                         let mut egui_ctx = egui_ctx.borrow_mut();
                         let mut device = device.borrow_mut();
                         let mut queue = queue.borrow_mut();
                         let mut app_output = app_output.borrow_mut();
                         {
                             // Begin frame
-                            let frame_time = get_frame_time(start_time);
                             let mut frame = FrameBuilder {
                                 info: IntegrationInfo {
                                     web_info: None,
-                                    cpu_usage: Some(frame_time),
+                                    cpu_usage: Some(cpu_usage),
                                     native_pixels_per_point: Some(state.pixels_per_point),
                                     prefer_dark_mode: None,
                                     name: INTEGRATION_NAME,
@@ -160,6 +169,7 @@ fn main() {
 
                         // End the UI frame. We could now handle the output and draw the UI with the backend.
                         let (output, shapes) = egui_ctx.end_frame();
+                        cpu_usage = (Instant::now() - egui_start).as_secs_f64() as f32;
                         state.fuse_output(window, &output);
                         let clipped_mesh = egui_ctx.tessellate(shapes);
                         let texture = egui_ctx.texture();
@@ -180,6 +190,7 @@ fn main() {
     let mut timer = Timer::new(1);
 
     while a.wait() {
+        let egui_start = Instant::now();
         let mut state = state.borrow_mut();
         let mut painter = painter.borrow_mut();
         let mut egui_ctx = egui_ctx.borrow_mut();
@@ -187,12 +198,10 @@ fn main() {
         let mut queue = queue.borrow_mut();
         let mut app_output = app_output.borrow_mut();
         {
-            // Begin frame
-            let frame_time = get_frame_time(start_time);
             let mut frame = FrameBuilder {
                 info: IntegrationInfo {
                     web_info: None,
-                    cpu_usage: Some(frame_time),
+                    cpu_usage: Some(cpu_usage),
                     native_pixels_per_point: Some(state.pixels_per_point),
                     prefer_dark_mode: None,
                     name: INTEGRATION_NAME,
@@ -213,6 +222,8 @@ fn main() {
 
         // End the UI frame. We could now handle the output and draw the UI with the backend.
         let (output, shapes) = egui_ctx.end_frame();
+        cpu_usage = (Instant::now() - egui_start).as_secs_f64() as f32;
+
         if app_output.quit {
             break;
         }
